!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.N. Lang                              |            !
!        | `---' | UFO date: 11/2018                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2018-11-29 12:10             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 1682
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: VFaF0 = 4
  integer, parameter :: VFaF1 = 5
  integer, parameter :: SVVS0 = 6
  integer, parameter :: VVVV0 = 7
  integer, parameter :: VVVV1 = 8
  integer, parameter :: UUaS0 = 9
  integer, parameter :: UUaV0 = 10
  integer, parameter :: SUUa0 = 11
  integer, parameter :: VVSS0 = 12
  integer, parameter :: UaSU0 = 13
  integer, parameter :: FFaV0 = 14
  integer, parameter :: FFaV1 = 15
  integer, parameter :: VVV0 = 16
  integer, parameter :: VVV1 = 17
  integer, parameter :: VVV2 = 18
  integer, parameter :: VVV3 = 19
  integer, parameter :: FSFa0 = 20
  integer, parameter :: FSFa1 = 21
  integer, parameter :: FSFa2 = 22
  integer, parameter :: VVS0 = 23
  integer, parameter :: FaVF0 = 24
  integer, parameter :: FaVF1 = 25
  integer, parameter :: UaVU0 = 26
  integer, parameter :: FaF0 = 27
  integer, parameter :: FaF1 = 28
  integer, parameter :: VSVS0 = 29
  integer, parameter :: FVFa0 = 30
  integer, parameter :: FVFa1 = 31
  integer, parameter :: VUaU0 = 32
  integer, parameter :: USUa0 = 33
  integer, parameter :: VV0 = 34
  integer, parameter :: VV1 = 35
  integer, parameter :: VV2 = 36
  integer, parameter :: SVSV0 = 37
  integer, parameter :: FaFS0 = 38
  integer, parameter :: FaFS1 = 39
  integer, parameter :: FaFS2 = 40
  integer, parameter :: FaFV0 = 41
  integer, parameter :: FaFV1 = 42
  integer, parameter :: SSSS0 = 43
  integer, parameter :: VS0 = 44
  integer, parameter :: SFFa0 = 45
  integer, parameter :: SFFa1 = 46
  integer, parameter :: SFFa2 = 47
  integer, parameter :: VUUa0 = 48
  integer, parameter :: SFaF0 = 49
  integer, parameter :: SFaF1 = 50
  integer, parameter :: SFaF2 = 51
  integer, parameter :: SVV0 = 52
  integer, parameter :: FaSF0 = 53
  integer, parameter :: FaSF1 = 54
  integer, parameter :: FaSF2 = 55
  integer, parameter :: SVS0 = 56
  integer, parameter :: FFa0 = 57
  integer, parameter :: FFa1 = 58
  integer, parameter :: VSS0 = 59
  integer, parameter :: VSV0 = 60
  integer, parameter :: SS0 = 61
  integer, parameter :: SSVV0 = 62
  integer, parameter :: SSV0 = 63
  integer, parameter :: SV0 = 64
  integer, parameter :: SSS0 = 65
  integer, parameter :: UVUa0 = 66
  integer, parameter :: VSSV0 = 67
  integer, parameter :: UaUS0 = 68
  integer, parameter :: VFFa0 = 69
  integer, parameter :: VFFa1 = 70
  integer, parameter :: SUaU0 = 71
  integer, parameter :: UaUV0 = 72
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c2f = "sq2/2"
  complex(dp), parameter :: c3 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c3f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c4 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c4f = "1/2"
  complex(dp), parameter :: c5 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c5f = "-1/2"
  complex(dp), parameter :: c6 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c6f = "i_*sq2/2"
  complex(dp), parameter :: c7 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c7f = "-i_*sq2/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:72) :: lorentz_rank = (/0, 0, 0, 1, 1, 0, 0, -1, 0, 1, 0&
                                             , 0, 0, 0, 0, 1, -1, -1, -1, 1, 1 &
                                             , 1, 0, 1, 1, 1, -1, -1, 0, 1, 1, &
                                             1, 0, -1, -1, -1, 0, 0, 0, 0, 0, 0&
                                             , 0, -1, 1, 1, 1, 1, 1, 1, 1, 0, 1&
                                             , 1, 1, 1, -1, -1, 1, 0, -1, 0, 1 &
                                             , -1, 0, 1, 0, 0, 1, 1, 0, 1/)
  integer, dimension(1:72) :: recola_base = (/5, 7, 9, 58, 53, -2, -11, 0, 1,  &
                                            161, 1, -4, 1, 15, 17, 12, 0, 0, 0 &
                                            , 25, 21, 27, 2, 51, 57, 166, 0, 0 &
                                            , -3, 31, 35, 162, 1, 0, 0, 0, -14 &
                                            , 6, 8, 10, 16, 18, -1, 0, 23, 28, &
                                            26, 163, 43, 46, 48, 13, 41, 45, 47&
                                            , 3, 0, 0, 4, 14, 0, -12, 11, 0, 1 &
                                            , 165, -13, 1, 33, 36, 1, 164/)
  integer, dimension(1:72) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0/)
  character(len=*), parameter :: model_timestamp = "Thu Nov 29 11:57:15 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(3361)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 296, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 962, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 974, check)
      call createCurrent(P_b, P_bAnti, P_g, 49, check)
      call createCurrent(P_muPlus, P_Zp, P_tauMinus, 1034, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 863, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 889, check)
      call createCurrent(P_WpPlus, P_tAnti, P_s, 736, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_H, 469, check)
      call createCurrent(P_WpMinus, P_dAnti, P_t, 1382, check)
      call createCurrent(P_Z, P_GPlus, P_H, P_WMinus, 867, check)
      call createCurrent(P_GPlus, P_uAnti, P_s, 1354, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, 1204, check)
      call createCurrent(P_WpPlus, P_s, P_cAnti, 1201, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 172, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, 193, check)
      call createCurrent(P_s, P_sAnti, P_H, 885, check)
      call createCurrent(P_cAnti, P_WpPlus, P_d, 61, check)
      call createCurrent(P_WpMinus, P_nu_e, P_ePlus, 98, check)
      call createCurrent(P_g, P_cAnti, P_c, 152, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 1347, check)
      call createCurrent(P_WPlus, P_g, P_WpMinus, P_g, 1542, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 1075, check)
      call createCurrent(P_Zp, P_s, P_sAnti, 1293, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 656, check)
      call createCurrent(P_u, P_cAnti, P_Zp, 1340, check)
      call createCurrent(P_c, P_GMinus, P_dAnti, 696, check)
      call createCurrent(P_Zp, P_b, P_dAnti, 382, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 718, check)
      call createCurrent(P_s, P_WpPlus, P_cAnti, 561, check)
      call createCurrent(P_Zp, P_tauMinus, P_tauPlus, 1429, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, 345, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 845, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 555, check)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_tauAnti, 810, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 670, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 963, check)
      call createCurrent(P_H, P_WPlus, P_A, P_GMinus, 1071, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, P_H, 617, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 440, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 103, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 180, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 993, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 320, check)
      call createCurrent(P_WMinus, P_H, P_Z, P_GPlus, 458, check)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_e, 601, check)
      call createCurrent(P_Zp, P_d, P_bAnti, 869, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 1485, check)
      call createCurrent(P_bAnti, P_b, P_g, 1180, check)
      call createCurrent(P_cAnti, P_Z, P_c, 510, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 351, check)
      call createCurrent(P_Zp, P_tauMinus, P_ePlus, 7, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 1196, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 322, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 1389, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 197, check)
      call createCurrent(P_t, P_Z, P_tAnti, 663, check)
      call createCurrent(P_G0, P_dAnti, P_d, 1060, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 1113, check)
      call createCurrent(P_s, P_Z, P_sAnti, 328, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 365, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 777, check)
      call createCurrent(P_H, P_cAnti, P_c, 704, check)
      call createCurrent(P_H, P_H, P_GPlus, P_GMinus, 315, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 830, check)
      call createCurrent(P_H, P_sAnti, P_d, 616, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 903, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 1259, check)
      call createCurrent(P_H, P_Z, P_GMinus, P_WPlus, 44, check)
      call createCurrent(P_G0, P_uAnti, P_u, 959, check)
      call createCurrent(P_nu_e, P_WpMinus, P_ePlus, 1461, check)
      call createCurrent(P_G0, P_c, P_cAnti, 105, check)
      call createCurrent(P_s, P_uAnti, P_GPlus, 317, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 185, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 285, check)
      call createCurrent(P_g, P_H, P_H, P_g, 1639, check)
      call createCurrent(P_WpPlus, P_WMinus, P_g, P_g, 1615, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 1304, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 1445, check)
      call createCurrent(P_Zp, P_sAnti, P_b, 80, check)
      call createCurrent(P_uAnti, P_s, P_WpPlus, 1459, check)
      call createCurrent(P_sAnti, P_WpMinus, P_u, 834, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 1657, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 1310, check)
      call createCurrent(P_tauMinus, P_Zp, P_muPlus, 59, check)
      call createCurrent(P_dAnti, P_t, P_WpMinus, 442, check)
      call createCurrent(P_Zp, P_muMinus, P_tauPlus, 768, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 1353, check)
      call createCurrent(P_sAnti, P_s, P_H, 1104, check)
      call createCurrent(P_A, P_H, P_GMinus, P_WPlus, 72, check)
      call createCurrent(P_dAnti, P_d, P_A, 1396, check)
      call createCurrent(P_WpPlus, P_WpMinus, P_g, P_g, 1571, check)
      call createCurrent(P_Z, P_uAnti, P_u, 576, check)
      call createCurrent(P_H, P_muMinus, P_muPlus, 1305, check)
      call createCurrent(P_tauMinus, P_H, P_tauPlus, 640, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 874, check)
      call createCurrent(P_Zp, P_A, P_g, P_g, 1558, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 429, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, P_H, 784, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, 1016, check)
      call createCurrent(P_GPlus, P_H, P_H, P_GMinus, 803, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_A, 1489, check)
      call createCurrent(P_dAnti, P_g, P_d, 690, check)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_e, 628, check)
      call createCurrent(P_c, P_cAnti, P_A, 695, check)
      call createCurrent(P_Zp, P_g, P_g, P_Z, 1554, check)
      call createCurrent(P_tauMinus, P_nu_muAnti, P_WpPlus, 207, check)
      call createCurrent(P_H, P_dAnti, P_s, 916, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 1596, check)
      call createCurrent(P_cAnti, P_GPlus, P_d, 631, check)
      call createCurrent(P_G0, P_sAnti, P_d, 1348, check)
      call createCurrent(P_tAnti, P_t, P_A, 247, check)
      call createCurrent(P_tauMinus, P_tauPlus, 1520, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 1011, check)
      call createCurrent(P_b, P_WpPlus, P_cAnti, 1245, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_H, 374, check)
      call createCurrent(P_eMinus, P_muPlus, P_Zp, 1482, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 543, check)
      call createCurrent(P_c, P_WpMinus, P_dAnti, 1272, check)
      call createCurrent(P_A, P_d, P_dAnti, 200, check)
      call createCurrent(P_dAnti, P_c, P_WMinus, 680, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, 1257, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 1000, check)
      call createCurrent(P_H, P_H, P_H, 590, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 762, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 483, check)
      call createCurrent(P_d, P_WpPlus, P_tAnti, 1391, check)
      call createCurrent(P_g, P_WpMinus, P_g, P_WpPlus, 1583, check)
      call createCurrent(P_muMinus, P_Zp, P_tauPlus, 1101, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_A, 939, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 1385, check)
      call createCurrent(P_uAnti, P_u, 1515, check)
      call createCurrent(P_eMinus, P_tauPlus, P_Zp, 1496, check)
      call createCurrent(P_WpMinus, P_bAnti, P_c, 1339, check)
      call createCurrent(P_Zp, P_bAnti, P_d, 1264, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_Z, 1128, check)
      call createCurrent(P_sAnti, P_A, P_s, 1078, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_Z, 407, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 462, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WpPlus, 589, check)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_muMinus, 841, check)
      call createCurrent(P_eMinus, P_ePlus, P_Zp, 1198, check)
      call createCurrent(P_uAnti, P_WPlus, P_s, 904, check)
      call createCurrent(P_tauPlus, P_Zp, P_tauMinus, 722, check)
      call createCurrent(P_d, P_H, P_sAnti, 82, check)
      call createCurrent(P_t, P_sAnti, P_WpMinus, 359, check)
      call createCurrent(P_uAnti, P_WpPlus, P_s, 377, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 639, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 1294, check)
      call createCurrent(P_uAnti, P_u, P_g, 1074, check)
      call createCurrent(P_nu_e, P_WpMinus, P_muPlus, 1283, check)
      call createCurrent(P_WpPlus, P_s, P_tAnti, 922, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 1188, check)
      call createCurrent(P_nu_eAnti, P_muMinus, P_WpPlus, 91, check)
      call createCurrent(P_GMinus, P_H, P_A, P_WPlus, 1362, check)
      call createCurrent(P_u, P_uAnti, 1514, check)
      call createCurrent(P_WpPlus, P_g, P_WpMinus, P_g, 1552, check)
      call createCurrent(P_cAnti, P_c, P_Zp, 794, check)
      call createCurrent(P_sAnti, P_H, P_s, 1221, check)
      call createCurrent(P_s, P_WpPlus, P_uAnti, 139, check)
      call createCurrent(P_tAnti, P_t, P_Z, 21, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 453, check)
      call createCurrent(P_s, P_sAnti, P_Zp, 767, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 232, check)
      call createCurrent(P_sAnti, P_s, P_Z, 1243, check)
      call createCurrent(P_g, P_WPlus, P_WpMinus, P_g, 1612, check)
      call createCurrent(P_sAnti, P_b, P_Zp, 517, check)
      call createCurrent(P_d, P_cAnti, P_GPlus, 910, check)
      call createCurrent(P_G0, P_H, P_G0, 607, check)
      call createCurrent(P_WMinus, P_dAnti, P_c, 370, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 679, check)
      call createCurrent(P_A, P_H, P_WMinus, P_GPlus, 664, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 1178, check)
      call createCurrent(P_s, P_H, P_sAnti, 839, check)
      call createCurrent(P_cAnti, P_c, 1507, check)
      call createCurrent(P_uAnti, P_u, P_Zp, 891, check)
      call createCurrent(P_cAnti, P_Zp, P_t, 30, check)
      call createCurrent(P_c, P_cAnti, P_G0, 902, check)
      call createCurrent(P_WpPlus, P_cAnti, P_b, 1493, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 1437, check)
      call createCurrent(P_tauMinus, P_Zp, P_ePlus, 512, check)
      call createCurrent(P_c, P_sAnti, P_WpMinus, 1235, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, 594, check)
      call createCurrent(P_G0, P_tAnti, P_t, 621, check)
      call createCurrent(P_dAnti, P_Zp, P_b, 995, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 174, check)
      call createCurrent(P_bAnti, P_Zp, P_d, 925, check)
      call createCurrent(P_s, P_dAnti, P_G0, 799, check)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_e, 40, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 1012, check)
      call createCurrent(P_cAnti, P_d, P_WPlus, 759, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 708, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, 334, check)
      call createCurrent(P_dAnti, P_d, P_g, 888, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 1018, check)
      call createCurrent(P_c, P_cAnti, 1513, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_A, 1003, check)
      call createCurrent(P_WpMinus, P_c, P_bAnti, 985, check)
      call createCurrent(P_tauMinus, P_Zp, P_tauPlus, 746, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 355, check)
      call createCurrent(P_s, P_Zp, P_sAnti, 1268, check)
      call createCurrent(P_A, P_H, P_GPlus, P_WMinus, 1093, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 1246, check)
      call createCurrent(P_eMinus, P_nu_tauAnti, P_WpPlus, 1330, check)
      call createCurrent(P_s, P_sAnti, P_g, 491, check)
      call createCurrent(P_uAnti, P_Z, P_u, 515, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 1015, check)
      call createCurrent(P_ePlus, P_nu_e, P_WpMinus, 1435, check)
      call createCurrent(P_A, P_GPlus, P_H, P_WMinus, 125, check)
      call createCurrent(P_d, P_dAnti, 1518, check)
      call createCurrent(P_H, P_A, P_WMinus, P_GPlus, 306, check)
      call createCurrent(P_A, P_Zp, P_g, P_g, 1632, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 1190, check)
      call createCurrent(P_H, P_G0, P_Z, 1267, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 109, check)
      call createCurrent(P_uAnti, P_d, P_WpPlus, 1154, check)
      call createCurrent(P_d, P_bAnti, P_Zp, 1285, check)
      call createCurrent(P_d, P_Zp, P_bAnti, 703, check)
      call createCurrent(P_Z, P_g, P_g, P_Zp, 1626, check)
      call createCurrent(P_g, P_WpPlus, P_g, P_WpMinus, 1567, check)
      call createCurrent(P_WpMinus, P_nu_tau, P_tauPlus, 95, check)
      call createCurrent(P_d, P_sAnti, P_H, 457, check)
      call createCurrent(P_d, P_GPlus, P_cAnti, 1418, check)
      call createCurrent(P_G0, P_d, P_dAnti, 905, check)
      call createCurrent(P_bAnti, P_G0, P_b, 753, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 763, check)
      call createCurrent(P_H, P_Z, P_G0, 521, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_H, 1079, check)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_eMinus, 842, check)
      call createCurrent(P_bAnti, P_Z, P_b, 379, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 26, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 1665, check)
      call createCurrent(P_d, P_dAnti, P_A, 1088, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 650, check)
      call createCurrent(P_s, P_GPlus, P_uAnti, 466, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WpMinus, 666, check)
      call createCurrent(P_H, P_muPlus, P_muMinus, 1058, check)
      call createCurrent(P_WPlus, P_WMinus, 1533, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 1043, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 1440, check)
      call createCurrent(P_dAnti, P_WpMinus, P_u, 816, check)
      call createCurrent(P_muMinus, P_muPlus, P_Zp, 48, check)
      call createCurrent(P_A, P_g, P_Zp, P_g, 1592, check)
      call createCurrent(P_u, P_Zp, P_cAnti, 558, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Zp, 1041, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_H, 251, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 261, check)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_eAnti, 773, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 645, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 1114, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 1255, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 1311, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 68, check)
      call createCurrent(P_Zp, P_g, P_g, P_g, 1642, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, P_H, 700, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 741, check)
      call createCurrent(P_d, P_G0, P_dAnti, 264, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 856, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 201, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 1561, check)
      call createCurrent(P_WpPlus, P_uAnti, P_d, 835, check)
      call createCurrent(P_Zp, P_tAnti, P_u, 1284, check)
      call createCurrent(P_tAnti, P_Zp, P_t, 1049, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 579, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 972, check)
      call createCurrent(P_d, P_cAnti, P_WPlus, 344, check)
      call createCurrent(P_g, P_g, P_WpPlus, P_WMinus, 1584, check)
      call createCurrent(P_muPlus, P_nu_tau, P_WpMinus, 1199, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WpMinus, 223, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 1538, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 1358, check)
      call createCurrent(P_u, P_dAnti, P_WpMinus, 1130, check)
      call createCurrent(P_A, P_s, P_sAnti, 1167, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 243, check)
      call createCurrent(P_nu_e, P_ePlus, P_WpMinus, 508, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, 101, check)
      call createCurrent(P_H, P_d, P_sAnti, 1070, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 423, check)
      call createCurrent(P_A, P_H, P_WPlus, P_GMinus, 441, check)
      call createCurrent(P_d, P_g, P_dAnti, 1124, check)
      call createCurrent(P_g, P_t, P_tAnti, 732, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 1373, check)
      call createCurrent(P_t, P_tAnti, 1512, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 449, check)
      call createCurrent(P_sAnti, P_WMinus, P_u, 946, check)
      call createCurrent(P_b, P_bAnti, P_Zp, 506, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 1527, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 316, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 122, check)
      call createCurrent(P_c, P_cAnti, P_g, 1224, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 1242, check)
      call createCurrent(P_c, P_cAnti, P_Zp, 1156, check)
      call createCurrent(P_u, P_uAnti, P_Z, 1308, check)
      call createCurrent(P_GPlus, P_H, P_Z, P_WMinus, 209, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 1365, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 234, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, 1295, check)
      call createCurrent(P_uAnti, P_WpPlus, P_d, 175, check)
      call createCurrent(P_g, P_b, P_bAnti, 684, check)
      call createCurrent(P_A, P_b, P_bAnti, 361, check)
      call createCurrent(P_g, P_g, P_H, P_H, 1562, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 551, check)
      call createCurrent(P_c, P_H, P_cAnti, 569, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 999, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 342, check)
      call createCurrent(P_tAnti, P_Zp, P_c, 518, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 1191, check)
      call createCurrent(P_GMinus, P_u, P_sAnti, 764, check)
      call createCurrent(P_uAnti, P_Zp, P_t, 321, check)
      call createCurrent(P_ePlus, P_eMinus, P_H, 432, check)
      call createCurrent(P_g, P_Zp, P_g, 1606, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 305, check)
      call createCurrent(P_d, P_H, P_dAnti, 394, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 1575, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 749, check)
      call createCurrent(P_sAnti, P_s, P_G0, 701, check)
      call createCurrent(P_WpMinus, P_sAnti, P_t, 147, check)
      call createCurrent(P_u, P_G0, P_uAnti, 283, check)
      call createCurrent(P_H, P_A, P_GMinus, P_WPlus, 393, check)
      call createCurrent(P_Zp, P_uAnti, P_u, 918, check)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_tauAnti, 643, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, 562, check)
      call createCurrent(P_G0, P_sAnti, P_s, 563, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, 528, check)
      call createCurrent(P_H, P_t, P_tAnti, 1357, check)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_tau, 840, check)
      call createCurrent(P_g, P_g, P_g, 1021, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, 852, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 473, check)
      call createCurrent(P_muPlus, P_Zp, P_eMinus, 815, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_H, 808, check)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_tau, 740, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 1425, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 1656, check)
      call createCurrent(P_Zp, P_sAnti, P_s, 1453, check)
      call createCurrent(P_Zp, P_t, P_uAnti, 367, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 552, check)
      call createCurrent(P_H, P_Z, P_WMinus, P_GPlus, 1483, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 1160, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 988, check)
      call createCurrent(P_WMinus, P_Z, P_H, P_GPlus, 811, check)
      call createCurrent(P_c, P_dAnti, P_WpMinus, 1162, check)
      call createCurrent(P_d, P_dAnti, P_G0, 1315, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_H, 1486, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 1271, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 982, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 954, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 807, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 623, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 1655, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 870, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 676, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 907, check)
      call createCurrent(P_WpMinus, P_dAnti, P_c, 554, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 758, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 398, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_H, 1059, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 966, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WpMinus, 430, check)
      call createCurrent(P_d, P_WpPlus, P_cAnti, 729, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 786, check)
      call createCurrent(P_WpMinus, P_nu_e, P_muPlus, 797, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 28, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 1020, check)
      call createCurrent(P_tauPlus, P_tauMinus, 1506, check)
      call createCurrent(P_c, P_Z, P_cAnti, 33, check)
      call createCurrent(P_g, P_H, P_g, P_H, 1576, check)
      call createCurrent(P_H, P_b, P_bAnti, 1349, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 1218, check)
      call createCurrent(P_WpMinus, P_g, P_WPlus, P_g, 1624, check)
      call createCurrent(P_WMinus, P_u, P_sAnti, 1475, check)
      call createCurrent(P_g, P_g, 1521, check)
      call createCurrent(P_Z, P_Z, P_H, 861, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, 253, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 503, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, 855, check)
      call createCurrent(P_WMinus, P_H, P_H, P_WPlus, 246, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 85, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 1322, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 1419, check)
      call createCurrent(P_A, P_WMinus, P_H, P_GPlus, 1096, check)
      call createCurrent(P_Zp, P_muMinus, P_ePlus, 534, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 348, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 502, check)
      call createCurrent(P_Zp, P_muPlus, P_muMinus, 1441, check)
      call createCurrent(P_u, P_uAnti, P_g, 924, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 1586, check)
      call createCurrent(P_nu_tauAnti, P_eMinus, P_WpPlus, 978, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 455, check)
      call createCurrent(P_GPlus, P_H, P_A, P_WMinus, 1105, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 983, check)
      call createCurrent(P_tauPlus, P_muMinus, P_Zp, 1183, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 1103, check)
      call createCurrent(P_g, P_g, P_Zp, P_Z, 1566, check)
      call createCurrent(P_WPlus, P_GMinus, 1500, check)
      call createCurrent(P_u, P_g, P_uAnti, 1462, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 372, check)
      call createCurrent(P_tAnti, P_u, P_Zp, 213, check)
      call createCurrent(P_dAnti, P_c, P_GMinus, 1038, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, 13, check)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_muAnti, 854, check)
      call createCurrent(P_H, P_s, P_sAnti, 804, check)
      call createCurrent(P_s, P_tAnti, P_WpPlus, 1380, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 70, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 837, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 980, check)
      call createCurrent(P_Zp, P_bAnti, P_s, 1208, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 1666, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_Z, 1397, check)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_eAnti, 1282, check)
      call createCurrent(P_ghZAnti, P_H, P_ghZ, 413, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_H, 1200, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 780, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 1422, check)
      call createCurrent(P_H, P_Z, P_Z, P_H, 1108, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, 176, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 1290, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 570, check)
      call createCurrent(P_nu_tau, P_WpMinus, P_tauPlus, 709, check)
      call createCurrent(P_d, P_G0, P_sAnti, 1028, check)
      call createCurrent(P_t, P_tAnti, P_A, 1047, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_H, 333, check)
      call createCurrent(P_H, P_ghWpAnti, P_ghWp, 1222, check)
      call createCurrent(P_H, P_tauPlus, P_tauMinus, 385, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 308, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 539, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_A, 1352, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 1564, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 1206, check)
      call createCurrent(P_t, P_tAnti, P_G0, 1270, check)
      call createCurrent(P_dAnti, P_WpMinus, P_t, 421, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 1323, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 1084, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 427, check)
      call createCurrent(P_Zp, P_muMinus, P_muPlus, 1037, check)
      call createCurrent(P_g, P_Zp, P_g, P_Z, 1539, check)
      call createCurrent(P_cAnti, P_s, P_WpPlus, 499, check)
      call createCurrent(P_nu_mu, P_ePlus, P_WpMinus, 208, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 467, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 1423, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 923, check)
      call createCurrent(P_GPlus, P_cAnti, P_d, 504, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 1413, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 153, check)
      call createCurrent(P_H, P_ghZAnti, P_ghZ, 1002, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 796, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_Z, 1449, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 212, check)
      call createCurrent(P_ePlus, P_Zp, P_tauMinus, 644, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 420, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 567, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 1676, check)
      call createCurrent(P_s, P_A, P_sAnti, 188, check)
      call createCurrent(P_s, P_WpPlus, P_tAnti, 102, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 933, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 523, check)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_eMinus, 106, check)
      call createCurrent(P_G0, P_H, P_Z, 1451, check)
      call createCurrent(P_d, P_cAnti, P_WpPlus, 1231, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 211, check)
      call createCurrent(P_GMinus, P_dAnti, P_c, 376, check)
      call createCurrent(P_dAnti, P_s, P_G0, 747, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_Z, 1471, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 1674, check)
      call createCurrent(P_cAnti, P_A, P_c, 369, check)
      call createCurrent(P_g, P_g, P_H, 1681, check)
      call createCurrent(P_muPlus, P_muMinus, P_H, 239, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 99, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 1436, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 162, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 75, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 533, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 138, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_H, 301, check)
      call createCurrent(P_muMinus, P_muPlus, 1508, check)
      call createCurrent(P_uAnti, P_Zp, P_c, 791, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 148, check)
      call createCurrent(P_bAnti, P_b, P_G0, 171, check)
      call createCurrent(P_g, P_g, P_WpPlus, P_WpMinus, 1620, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 1667, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 783, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 634, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 705, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 114, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 1388, check)
      call createCurrent(P_dAnti, P_d, P_Z, 1240, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 657, check)
      call createCurrent(P_sAnti, P_u, P_GMinus, 124, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_A, 1076, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 941, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 1115, check)
      call createCurrent(P_b, P_bAnti, P_G0, 113, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 1230, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 850, check)
      call createCurrent(P_WPlus, P_Z, P_H, P_GMinus, 636, check)
      call createCurrent(P_sAnti, P_t, P_WpMinus, 739, check)
      call createCurrent(P_H, P_sAnti, P_s, 957, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 883, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 702, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 1249, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 397, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 228, check)
      call createCurrent(P_WpMinus, P_nu_mu, P_tauPlus, 27, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_H, 117, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 707, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 260, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 465, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 1212, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, 1456, check)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_mu, 136, check)
      call createCurrent(P_g, P_g, P_Z, P_Zp, 1645, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 240, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 1504, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 418, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 1044, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 330, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 630, check)
      call createCurrent(P_G0, P_Z, 1535, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 158, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 1673, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 1424, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 1569, check)
      call createCurrent(P_tAnti, P_c, P_Zp, 104, check)
      call createCurrent(P_WPlus, P_uAnti, P_s, 1317, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 84, check)
      call createCurrent(P_sAnti, P_c, P_WpMinus, 917, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 326, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 332, check)
      call createCurrent(P_G0, P_bAnti, P_b, 199, check)
      call createCurrent(P_uAnti, P_b, P_WpPlus, 403, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 184, check)
      call createCurrent(P_sAnti, P_WpMinus, P_c, 94, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, 60, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 1250, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 131, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WpPlus, 1416, check)
      call createCurrent(P_Zp, P_muPlus, P_eMinus, 1216, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 143, check)
      call createCurrent(P_t, P_WpMinus, P_dAnti, 63, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 1085, check)
      call createCurrent(P_uAnti, P_s, P_GPlus, 899, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 637, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 1326, check)
      call createCurrent(P_c, P_WpMinus, P_sAnti, 464, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 1661, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 1146, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 1523, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 620, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 1338, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 1628, check)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_eMinus, 1487, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 329, check)
      call createCurrent(P_g, P_g, P_Zp, P_A, 1607, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_A, 416, check)
      call createCurrent(P_WMinus, P_H, P_A, P_GPlus, 1368, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 439, check)
      call createCurrent(P_Z, P_u, P_uAnti, 203, check)
      call createCurrent(P_H, P_g, P_g, P_H, 1619, check)
      call createCurrent(P_Zp, P_g, P_Zp, P_g, 1664, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 537, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 490, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_A, 58, check)
      call createCurrent(P_u, P_sAnti, P_GMinus, 353, check)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_tauMinus, 748, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 942, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 750, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 879, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 1355, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 1677, check)
      call createCurrent(P_bAnti, P_t, P_WpMinus, 409, check)
      call createCurrent(P_H, P_GPlus, P_A, P_WMinus, 1202, check)
      call createCurrent(P_uAnti, P_A, P_u, 973, check)
      call createCurrent(P_g, P_g, P_Zp, P_Zp, 1636, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 258, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 547, check)
      call createCurrent(P_Z, P_H, P_WMinus, P_GPlus, 352, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 156, check)
      call createCurrent(P_g, P_g, P_A, P_g, 1551, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 896, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 581, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 189, check)
      call createCurrent(P_muPlus, P_H, P_muMinus, 485, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 177, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 1469, check)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_eAnti, 1186, check)
      call createCurrent(P_d, P_sAnti, P_G0, 110, check)
      call createCurrent(P_nu_muAnti, P_eMinus, P_WpPlus, 179, check)
      call createCurrent(P_H, P_g, P_g, 1623, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_A, 872, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 1503, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 1129, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 1448, check)
      call createCurrent(P_b, P_Z, P_bAnti, 649, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 339, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 289, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 1086, check)
      call createCurrent(P_g, P_WpPlus, P_g, P_WMinus, 1550, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 610, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 414, check)
      call createCurrent(P_Zp, P_c, P_tAnti, 1024, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 18, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 611, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 719, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 1591, check)
      call createCurrent(P_H, P_ghZ, P_ghZAnti, 887, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WpPlus, 1594, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_Z, 585, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 693, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 111, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 116, check)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_tau, 140, check)
      call createCurrent(P_H, P_Z, P_Z, 1447, check)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_muMinus, 1394, check)
      call createCurrent(P_G0, P_b, P_bAnti, 1106, check)
      call createCurrent(P_H, P_g, P_H, P_g, 1635, check)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_e, 157, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 513, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 1395, check)
      call createCurrent(P_muMinus, P_nu_eAnti, P_WpPlus, 802, check)
      call createCurrent(P_u, P_uAnti, P_Zp, 1061, check)
      call createCurrent(P_s, P_bAnti, P_Zp, 880, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 1484, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 926, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 1547, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 691, check)
      call createCurrent(P_G0, P_dAnti, P_s, 415, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 1017, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 949, check)
      call createCurrent(P_c, P_cAnti, P_H, 1406, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 527, check)
      call createCurrent(P_H, P_H, P_H, P_H, 608, check)
      call createCurrent(P_g, P_g, P_Zp, 1668, check)
      call createCurrent(P_Zp, P_s, P_dAnti, 1195, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 1112, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 1350, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 492, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 1261, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 214, check)
      call createCurrent(P_c, P_WMinus, P_dAnti, 812, check)
      call createCurrent(P_Zp, P_g, P_g, 1660, check)
      call createCurrent(P_nu_e, P_tauPlus, P_WpMinus, 250, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_H, 577, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 1498, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 1155, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 751, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 844, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 642, check)
      call createCurrent(P_eMinus, P_ePlus, 1510, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 284, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 9, check)
      call createCurrent(P_dAnti, P_d, P_H, 1300, check)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_e, 19, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 531, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, 1149, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 1237, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 291, check)
      call createCurrent(P_d, P_Zp, P_sAnti, 1377, check)
      call createCurrent(P_tauMinus, P_ePlus, P_Zp, 633, check)
      call createCurrent(P_eMinus, P_Zp, P_ePlus, 1140, check)
      call createCurrent(P_tauPlus, P_Zp, P_muMinus, 979, check)
      call createCurrent(P_Z, P_H, P_Z, 341, check)
      call createCurrent(P_A, P_tAnti, P_t, 1072, check)
      call createCurrent(P_nu_mu, P_WpMinus, P_tauPlus, 821, check)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_tauAnti, 1400, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 15, check)
      call createCurrent(P_nu_e, P_muPlus, P_WpMinus, 274, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 1446, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 218, check)
      call createCurrent(P_Z, P_d, P_dAnti, 829, check)
      call createCurrent(P_g, P_A, P_Zp, P_g, 1582, check)
      call createCurrent(P_s, P_Zp, P_bAnti, 494, check)
      call createCurrent(P_tAnti, P_t, P_Zp, 1097, check)
      call createCurrent(P_g, P_g, P_WpMinus, P_WpPlus, 1577, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 929, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 900, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 838, check)
      call createCurrent(P_WpMinus, P_c, P_sAnti, 618, check)
      call createCurrent(P_WPlus, P_H, P_Z, P_GMinus, 678, check)
      call createCurrent(P_g, P_c, P_cAnti, 1030, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 64, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, P_H, 271, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 438, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 450, check)
      call createCurrent(P_bAnti, P_s, P_Zp, 1102, check)
      call createCurrent(P_dAnti, P_G0, P_s, 526, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 1248, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 480, check)
      call createCurrent(P_sAnti, P_d, P_G0, 399, check)
      call createCurrent(P_c, P_WpMinus, P_bAnti, 1228, check)
      call createCurrent(P_A, P_WPlus, P_H, P_GMinus, 532, check)
      call createCurrent(P_Zp, P_c, P_uAnti, 653, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 505, check)
      call createCurrent(P_tauPlus, P_H, P_tauMinus, 1175, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 530, check)
      call createCurrent(P_WMinus, P_GPlus, 1522, check)
      call createCurrent(P_Zp, P_u, P_cAnti, 952, check)
      call createCurrent(P_g, P_sAnti, P_s, 1184, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 445, check)
      call createCurrent(P_GMinus, P_WPlus, 1529, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 615, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WpPlus, 635, check)
      call createCurrent(P_A, P_t, P_tAnti, 182, check)
      call createCurrent(P_sAnti, P_GMinus, P_u, 1042, check)
      call createCurrent(P_b, P_G0, P_bAnti, 241, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 669, check)
      call createCurrent(P_GPlus, P_s, P_uAnti, 1091, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 730, check)
      call createCurrent(P_Z, P_s, P_sAnti, 363, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 674, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 683, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 65, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 452, check)
      call createCurrent(P_sAnti, P_s, P_g, 1420, check)
      call createCurrent(P_WpMinus, P_WPlus, P_g, P_g, 1585, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 1647, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 787, check)
      call createCurrent(P_cAnti, P_Zp, P_u, 262, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 1276, check)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_muMinus, 655, check)
      call createCurrent(P_tAnti, P_t, P_g, 498, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 77, check)
      call createCurrent(P_s, P_dAnti, P_H, 1213, check)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_tauMinus, 245, check)
      call createCurrent(P_H, P_Z, P_GPlus, P_WMinus, 168, check)
      call createCurrent(P_A, P_GMinus, P_H, P_WPlus, 1173, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 776, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 955, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 735, check)
      call createCurrent(P_g, P_Z, P_g, P_Zp, 1658, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 90, check)
      call createCurrent(P_H, P_bAnti, P_b, 337, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 1378, check)
      call createCurrent(P_t, P_WpMinus, P_sAnti, 726, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, 45, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 1133, check)
      call createCurrent(P_uAnti, P_u, P_Z, 257, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 346, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 1163, check)
      call createCurrent(P_tAnti, P_b, P_WpPlus, 877, check)
      call createCurrent(P_GPlus, P_Z, P_H, P_WMinus, 43, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 378, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 595, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 1472, check)
      call createCurrent(P_GMinus, P_H, P_H, P_GPlus, 482, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 1336, check)
      call createCurrent(P_WpPlus, P_cAnti, P_d, 1404, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 5, check)
      call createCurrent(P_sAnti, P_s, P_Zp, 996, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 560, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 1337, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 313, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_H, 686, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, 591, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 516, check)
      call createCurrent(P_A, P_g, P_g, P_A, 1659, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 1203, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 324, check)
      call createCurrent(P_eMinus, P_ePlus, P_H, 1142, check)
      call createCurrent(P_A, P_bAnti, P_b, 235, check)
      call createCurrent(P_g, P_WpPlus, P_WpMinus, P_g, 1555, check)
      call createCurrent(P_ePlus, P_eMinus, 1501, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 310, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 388, check)
      call createCurrent(P_Zp, P_g, P_Z, P_g, 1651, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 1679, check)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_mu, 987, check)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_mu, 820, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 210, check)
      call createCurrent(P_uAnti, P_GPlus, P_s, 1364, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 447, check)
      call createCurrent(P_G0, P_H, P_H, P_G0, 943, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, 689, check)
      call createCurrent(P_dAnti, P_d, P_Zp, 391, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 277, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 1638, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 1119, check)
      call createCurrent(P_H, P_WMinus, P_A, P_GPlus, 216, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 1116, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 771, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 1122, check)
      call createCurrent(P_Zp, P_t, P_cAnti, 1316, check)
      call createCurrent(P_sAnti, P_g, P_s, 1321, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 1320, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 1519, check)
      call createCurrent(P_WpMinus, P_t, P_dAnti, 1121, check)
      call createCurrent(P_G0, P_s, P_sAnti, 435, check)
      call createCurrent(P_Zp, P_eMinus, P_tauPlus, 848, check)
      call createCurrent(P_Z, P_H, P_G0, 1335, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 1383, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 1526, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 1232, check)
      call createCurrent(P_WpMinus, P_sAnti, P_c, 597, check)
      call createCurrent(P_Zp, P_eMinus, P_ePlus, 545, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 1675, check)
      call createCurrent(P_tAnti, P_t, P_G0, 687, check)
      call createCurrent(P_WpMinus, P_g, P_g, P_WPlus, 1650, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, 566, check)
      call createCurrent(P_Zp, P_u, P_tAnti, 205, check)
      call createCurrent(P_s, P_G0, P_sAnti, 614, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WpMinus, 1654, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 1278, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 592, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 1141, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WpMinus, 263, check)
      call createCurrent(P_Zp, P_tAnti, P_c, 475, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 206, check)
      call createCurrent(P_tauPlus, P_eMinus, P_Zp, 1313, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 927, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 860, check)
      call createCurrent(P_c, P_uAnti, P_Zp, 1001, check)
      call createCurrent(P_Zp, P_tAnti, P_t, 1244, check)
      call createCurrent(P_d, P_sAnti, P_Zp, 1410, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 408, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 1371, check)
      call createCurrent(P_Zp, P_cAnti, P_c, 743, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 1324, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 493, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 1110, check)
      call createCurrent(P_G0, P_G0, P_H, P_H, 1026, check)
      call createCurrent(P_tAnti, P_A, P_t, 1433, check)
      call createCurrent(P_A, P_g, P_g, P_Zp, 1680, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 118, check)
      call createCurrent(P_u, P_Z, P_uAnti, 1495, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 1598, check)
      call createCurrent(P_s, P_sAnti, P_A, 609, check)
      call createCurrent(P_t, P_tAnti, P_g, 511, check)
      call createCurrent(P_uAnti, P_s, P_WPlus, 711, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 0, check)
      call createCurrent(P_bAnti, P_d, P_Zp, 128, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 921, check)
      call createCurrent(P_Z, P_bAnti, P_b, 652, check)
      call createCurrent(P_WPlus, P_H, P_H, P_WMinus, 1280, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 947, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 914, check)
      call createCurrent(P_g, P_WMinus, P_WpPlus, P_g, 1641, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_A, 1052, check)
      call createCurrent(P_Z, P_dAnti, P_d, 1262, check)
      call createCurrent(P_b, P_cAnti, P_WpPlus, 190, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 1301, check)
      call createCurrent(P_bAnti, P_b, P_Z, 481, check)
      call createCurrent(P_A, P_c, P_cAnti, 187, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 270, check)
      call createCurrent(P_A, P_uAnti, P_u, 1009, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 752, check)
      call createCurrent(P_Zp, P_cAnti, P_u, 89, check)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_eMinus, 1376, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 1460, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 1578, check)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_eAnti, 227, check)
      call createCurrent(P_b, P_A, P_bAnti, 1219, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 1050, check)
      call createCurrent(P_g, P_Z, P_Zp, P_g, 1543, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WpPlus, 1652, check)
      call createCurrent(P_s, P_g, P_sAnti, 1444, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 1048, check)
      call createCurrent(P_u, P_sAnti, P_WMinus, 149, check)
      call createCurrent(P_uAnti, P_Zp, P_u, 875, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 1291, check)
      call createCurrent(P_WpMinus, P_bAnti, P_t, 1473, check)
      call createCurrent(P_A, P_g, P_g, P_g, 1556, check)
      call createCurrent(P_d, P_uAnti, P_WpPlus, 186, check)
      call createCurrent(P_Zp, P_dAnti, P_s, 224, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 314, check)
      call createCurrent(P_muMinus, P_muPlus, P_H, 11, check)
      call createCurrent(P_H, P_s, P_dAnti, 66, check)
      call createCurrent(P_dAnti, P_d, 1502, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 1229, check)
      call createCurrent(P_s, P_sAnti, P_Z, 1346, check)
      call createCurrent(P_g, P_H, P_g, 1634, check)
      call createCurrent(P_Zp, P_s, P_bAnti, 557, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 401, check)
      call createCurrent(P_sAnti, P_Zp, P_b, 641, check)
      call createCurrent(P_g, P_d, P_dAnti, 112, check)
      call createCurrent(P_cAnti, P_g, P_c, 1260, check)
      call createCurrent(P_A, P_cAnti, P_c, 574, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 1139, check)
      call createCurrent(P_WpPlus, P_g, P_g, P_WpMinus, 1593, check)
      call createCurrent(P_g, P_tAnti, P_t, 849, check)
      call createCurrent(P_s, P_dAnti, P_Zp, 123, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 50, check)
      call createCurrent(P_H, P_GMinus, P_Z, P_WPlus, 1039, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 215, check)
      call createCurrent(P_g, P_g, P_g, P_Zp, 1580, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, 87, check)
      call createCurrent(P_H, P_tauMinus, P_tauPlus, 1266, check)
      call createCurrent(P_t, P_g, P_tAnti, 913, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 671, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 1491, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 487, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 1443, check)
      call createCurrent(P_WpMinus, P_nu_tau, P_muPlus, 477, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_Z, 789, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 486, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 107, check)
      call createCurrent(P_WMinus, P_WpPlus, P_g, P_g, 1613, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 217, check)
      call createCurrent(P_nu_mu, P_WpMinus, P_ePlus, 1263, check)
      call createCurrent(P_G0, P_u, P_uAnti, 809, check)
      call createCurrent(P_muPlus, P_muMinus, 1509, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 1402, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 150, check)
      call createCurrent(P_uAnti, P_c, P_Zp, 965, check)
      call createCurrent(P_b, P_dAnti, P_Zp, 647, check)
      call createCurrent(P_uAnti, P_G0, P_u, 596, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 144, check)
      call createCurrent(P_u, P_Zp, P_tAnti, 688, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 535, check)
      call createCurrent(P_Zp, P_ePlus, P_muMinus, 714, check)
      call createCurrent(P_sAnti, P_d, P_Zp, 660, check)
      call createCurrent(P_GPlus, P_A, P_H, P_WMinus, 699, check)
      call createCurrent(P_nu_mu, P_tauPlus, P_WpMinus, 1148, check)
      call createCurrent(P_bAnti, P_b, P_Zp, 876, check)
      call createCurrent(P_muMinus, P_Zp, P_ePlus, 975, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 1111, check)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_eAnti, 1217, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 1187, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 1275, check)
      call createCurrent(P_H, P_H, P_g, P_g, 1559, check)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_tauAnti, 1172, check)
      call createCurrent(P_Z, P_b, P_bAnti, 697, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 303, check)
      call createCurrent(P_t, P_tAnti, P_H, 146, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 1164, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 1046, check)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_eMinus, 604, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 986, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 565, check)
      call createCurrent(P_H, P_WMinus, P_H, P_WPlus, 1403, check)
      call createCurrent(P_g, P_u, P_uAnti, 204, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 1328, check)
      call createCurrent(P_tAnti, P_WpPlus, P_s, 715, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 53, check)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_tauAnti, 142, check)
      call createCurrent(P_Zp, P_Zp, 1505, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 1466, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, 1138, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 433, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 497, check)
      call createCurrent(P_sAnti, P_s, P_A, 836, check)
      call createCurrent(P_tAnti, P_d, P_WpPlus, 632, check)
      call createCurrent(P_muPlus, P_tauMinus, P_Zp, 627, check)
      call createCurrent(P_H, P_Z, P_H, P_Z, 130, check)
      call createCurrent(P_WpPlus, P_tAnti, P_b, 524, check)
      call createCurrent(P_WpPlus, P_uAnti, P_s, 225, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 88, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 612, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 375, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 1077, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 456, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_H, 343, check)
      call createCurrent(P_Zp, P_Z, P_g, P_g, 1541, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 912, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 1004, check)
      call createCurrent(P_b, P_uAnti, P_WpPlus, 981, check)
      call createCurrent(P_cAnti, P_c, P_g, 677, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 340, check)
      call createCurrent(P_Zp, P_eMinus, P_muPlus, 1369, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 819, check)
      call createCurrent(P_GMinus, P_sAnti, P_u, 519, check)
      call createCurrent(P_Zp, P_ePlus, P_eMinus, 3, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 1007, check)
      call createCurrent(P_u, P_GMinus, P_sAnti, 651, check)
      call createCurrent(P_A, P_g, P_A, P_g, 1622, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_Z, 544, check)
      call createCurrent(P_A, P_sAnti, P_s, 1279, check)
      call createCurrent(P_tAnti, P_t, P_H, 744, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 1234, check)
      call createCurrent(P_d, P_WpPlus, P_uAnti, 368, check)
      call createCurrent(P_sAnti, P_u, P_WpMinus, 582, check)
      call createCurrent(P_d, P_dAnti, P_Z, 1366, check)
      call createCurrent(P_Zp, P_tauPlus, P_tauMinus, 1303, check)
      call createCurrent(P_nu_e, P_WpMinus, P_tauPlus, 956, check)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_tau, 121, check)
      call createCurrent(P_dAnti, P_H, P_d, 798, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 894, check)
      call createCurrent(P_tAnti, P_H, P_t, 8, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 1467, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 584, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 1006, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 1603, check)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_e, 868, check)
      call createCurrent(P_GMinus, P_A, P_H, P_WPlus, 14, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 843, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 74, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 1136, check)
      call createCurrent(P_WpMinus, P_WpPlus, 1525, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 325, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 911, check)
      call createCurrent(P_cAnti, P_u, P_Zp, 1080, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 665, check)
      call createCurrent(P_sAnti, P_G0, P_s, 141, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 37, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 468, check)
      call createCurrent(P_cAnti, P_t, P_Zp, 1454, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 765, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 1014, check)
      call createCurrent(P_b, P_Zp, P_sAnti, 108, check)
      call createCurrent(P_b, P_WpPlus, P_tAnti, 1192, check)
      call createCurrent(P_GMinus, P_c, P_dAnti, 1480, check)
      call createCurrent(P_b, P_bAnti, P_A, 230, check)
      call createCurrent(P_c, P_bAnti, P_WpMinus, 127, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 120, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 259, check)
      call createCurrent(P_g, P_g, P_g, P_g, 56, check)
      call createCurrent(P_dAnti, P_WpMinus, P_c, 307, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 1457, check)
      call createCurrent(P_WpMinus, P_u, P_dAnti, 1374, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 1179, check)
      call createCurrent(P_H, P_Z, P_WPlus, P_GMinus, 625, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 1625, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 1494, check)
      call createCurrent(P_WpPlus, P_b, P_cAnti, 788, check)
      call createCurrent(P_Z, P_H, P_H, P_Z, 1143, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 1125, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 930, check)
      call createCurrent(P_WPlus, P_cAnti, P_d, 668, check)
      call createCurrent(P_WpMinus, P_t, P_bAnti, 169, check)
      call createCurrent(P_H, P_d, P_dAnti, 300, check)
      call createCurrent(P_Zp, P_dAnti, P_b, 984, check)
      call createCurrent(P_Z, P_GMinus, P_H, P_WPlus, 1189, check)
      call createCurrent(P_WpMinus, P_u, P_bAnti, 1332, check)
      call createCurrent(P_tAnti, P_WpPlus, P_b, 71, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 51, check)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_tauMinus, 1174, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 1117, check)
      call createCurrent(P_dAnti, P_Zp, P_s, 233, check)
      call createCurrent(P_dAnti, P_c, P_WpMinus, 12, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_H, 1384, check)
      call createCurrent(P_H, P_GMinus, P_H, P_GPlus, 1207, check)
      call createCurrent(P_bAnti, P_c, P_WpMinus, 78, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 603, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 35, check)
      call createCurrent(P_bAnti, P_A, P_b, 323, check)
      call createCurrent(P_bAnti, P_Zp, P_s, 219, check)
      call createCurrent(P_G0, P_t, P_tAnti, 1209, check)
      call createCurrent(P_cAnti, P_c, P_G0, 1254, check)
      call createCurrent(P_Zp, P_d, P_sAnti, 619, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_A, 6, check)
      call createCurrent(P_bAnti, P_g, P_b, 1205, check)
      call createCurrent(P_cAnti, P_d, P_GPlus, 866, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 254, check)
      call createCurrent(P_muPlus, P_Zp, P_muMinus, 32, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 350, check)
      call createCurrent(P_muMinus, P_H, P_muPlus, 422, check)
      call createCurrent(P_Zp, P_cAnti, P_t, 55, check)
      call createCurrent(P_Zp, P_tauPlus, P_eMinus, 831, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 1067, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 425, check)
      call createCurrent(P_tauPlus, P_nu_mu, P_WpMinus, 940, check)
      call createCurrent(P_g, P_uAnti, P_u, 785, check)
      call createCurrent(P_dAnti, P_s, P_H, 92, check)
      call createCurrent(P_Z, P_H, P_Z, P_H, 1171, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 638, check)
      call createCurrent(P_Zp, P_ePlus, P_tauMinus, 252, check)
      call createCurrent(P_WpMinus, P_bAnti, P_u, 1177, check)
      call createCurrent(P_Z, P_Zp, P_g, P_g, 1653, check)
      call createCurrent(P_H, P_ghWmAnti, P_ghWm, 249, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 724, check)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_mu, 67, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_H, 857, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_H, 761, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 622, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 571, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 1211, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 1351, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WpPlus, 546, check)
      call createCurrent(P_g, P_Zp, P_Zp, P_g, 1602, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 1605, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 154, check)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_eMinus, 961, check)
      call createCurrent(P_dAnti, P_GMinus, P_c, 1182, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 231, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 1312, check)
      call createCurrent(P_Zp, P_b, P_bAnti, 1094, check)
      call createCurrent(P_Zp, P_Zp, P_g, P_g, 1572, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 1107, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_Z, 1476, check)
      call createCurrent(P_Z, P_cAnti, P_c, 151, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 267, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 1269, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 238, check)
      call createCurrent(P_nu_mu, P_WpMinus, P_muPlus, 132, check)
      call createCurrent(P_cAnti, P_H, P_c, 222, check)
      call createCurrent(P_H, P_H, 1499, check)
      call createCurrent(P_G0, P_G0, P_H, 360, check)
      call createCurrent(P_WpMinus, P_WpPlus, P_g, P_g, 1611, check)
      call createCurrent(P_bAnti, P_Zp, P_b, 886, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 349, check)
      call createCurrent(P_cAnti, P_c, P_A, 685, check)
      call createCurrent(P_WpMinus, P_nu_mu, P_ePlus, 191, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 681, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 1065, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 1288, check)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_tauMinus, 932, check)
      call createCurrent(P_t, P_tAnti, P_Zp, 198, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 833, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_H, 54, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, 471, check)
      call createCurrent(P_t, P_Zp, P_cAnti, 1307, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 287, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 96, check)
      call createCurrent(P_WpPlus, P_g, P_WMinus, P_g, 1618, check)
      call createCurrent(P_g, P_WpMinus, P_WpPlus, P_g, 1610, check)
      call createCurrent(P_t, P_dAnti, P_WpMinus, 600, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 1375, check)
      call createCurrent(P_Z, P_G0, P_H, 1165, check)
      call createCurrent(P_tAnti, P_G0, P_t, 1241, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 1095, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 606, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 964, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 728, check)
      call createCurrent(P_tAnti, P_Z, P_t, 451, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 717, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 299, check)
      call createCurrent(P_d, P_dAnti, P_H, 194, check)
      call createCurrent(P_Z, P_WMinus, P_H, P_GPlus, 478, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 950, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 266, check)
      call createCurrent(P_Zp, P_u, P_uAnti, 161, check)
      call createCurrent(P_cAnti, P_WpPlus, P_b, 587, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 280, check)
      call createCurrent(P_d, P_WPlus, P_cAnti, 1251, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 1197, check)
      call createCurrent(P_g, P_Zp, P_Z, P_g, 1669, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 1227, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 1013, check)
      call createCurrent(P_s, P_WPlus, P_uAnti, 915, check)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_tau, 781, check)
      call createCurrent(P_g, P_A, P_A, P_g, 1670, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 509, check)
      call createCurrent(P_s, P_H, P_dAnti, 769, check)
      call createCurrent(P_sAnti, P_Z, P_s, 133, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 958, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 1672, check)
      call createCurrent(P_WpPlus, P_b, P_uAnti, 593, check)
      call createCurrent(P_G0, P_H, P_G0, P_H, 825, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 1560, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 1386, check)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, 1144, check)
      call createCurrent(P_Zp, P_d, P_dAnti, 1398, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, 895, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 824, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 1455, check)
      call createCurrent(P_sAnti, P_d, P_H, 792, check)
      call createCurrent(P_dAnti, P_A, P_d, 29, check)
      call createCurrent(P_GPlus, P_WMinus, 1528, check)
      call createCurrent(P_H, P_GMinus, P_A, P_WPlus, 276, check)
      call createCurrent(P_Z, P_tAnti, P_t, 522, check)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_muAnti, 1481, check)
      call createCurrent(P_b, P_tAnti, P_WpPlus, 42, check)
      call createCurrent(P_bAnti, P_WpMinus, P_t, 1157, check)
      call createCurrent(P_ePlus, P_nu_tau, P_WpMinus, 1256, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 331, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 1411, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 977, check)
      call createCurrent(P_ePlus, P_Zp, P_eMinus, 373, check)
      call createCurrent(P_s, P_sAnti, 1536, check)
      call createCurrent(P_t, P_Zp, P_uAnti, 568, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WpMinus, 1599, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_H, 286, check)
      call createCurrent(P_H, P_H, P_WMinus, P_WPlus, 1434, check)
      call createCurrent(P_WpPlus, P_b, P_tAnti, 57, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 851, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 1127, check)
      call createCurrent(P_s, P_cAnti, P_WpPlus, 290, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 1627, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 1363, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 1035, check)
      call createCurrent(P_g, P_Zp, P_g, P_Zp, 1600, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 971, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 772, check)
      call createCurrent(P_H, P_WMinus, P_Z, P_GPlus, 1120, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 17, check)
      call createCurrent(P_Zp, P_t, P_tAnti, 327, check)
      call createCurrent(P_g, P_g, P_A, P_A, 1557, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_A, 1427, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 1166, check)
      call createCurrent(P_muPlus, P_muMinus, P_Zp, 920, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 793, check)
      call createCurrent(P_g, P_WpMinus, P_g, P_WPlus, 1640, check)
      call createCurrent(P_dAnti, P_WMinus, P_c, 1134, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 25, check)
      call createCurrent(P_WPlus, P_d, P_cAnti, 1019, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 586, check)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_mu, 716, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 1258, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 336, check)
      call createCurrent(P_H, P_u, P_uAnti, 1151, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 661, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 1273, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 994, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, 1233, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 898, check)
      call createCurrent(P_WpPlus, P_cAnti, P_s, 1054, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 1169, check)
      call createCurrent(P_Z, P_H, P_GMinus, P_WPlus, 244, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 1056, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 500, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 723, check)
      call createCurrent(P_c, P_Zp, P_cAnti, 1370, check)
      call createCurrent(P_g, P_bAnti, P_b, 297, check)
      call createCurrent(P_sAnti, P_Zp, P_s, 989, check)
      call createCurrent(P_dAnti, P_Zp, P_d, 948, check)
      call createCurrent(P_GPlus, P_d, P_cAnti, 801, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 738, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, P_H, 1147, check)
      call createCurrent(P_sAnti, P_u, P_WMinus, 1214, check)
      call createCurrent(P_uAnti, P_t, P_Zp, 1238, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 1253, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 549, check)
      call createCurrent(P_tAnti, P_WpPlus, P_d, 39, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 366, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 167, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 990, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 428, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 1359, check)
      call createCurrent(P_Zp, P_uAnti, P_c, 1100, check)
      call createCurrent(P_u, P_tAnti, P_Zp, 893, check)
      call createCurrent(P_bAnti, P_b, P_A, 292, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 380, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 692, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 822, check)
      call createCurrent(P_WpPlus, P_d, P_tAnti, 602, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 195, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 823, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 672, check)
      call createCurrent(P_eMinus, P_H, P_ePlus, 1022, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 1158, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 444, check)
      call createCurrent(P_u, P_sAnti, P_WpMinus, 859, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 828, check)
      call createCurrent(P_H, P_WPlus, P_H, P_WMinus, 1152, check)
      call createCurrent(P_cAnti, P_Zp, P_c, 934, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_H, 384, check)
      call createCurrent(P_WpPlus, P_g, P_g, P_WMinus, 1609, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 165, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, P_H, 770, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 396, check)
      call createCurrent(P_nu_tau, P_WpMinus, P_ePlus, 575, check)
      call createCurrent(P_b, P_bAnti, 1516, check)
      call createCurrent(P_c, P_dAnti, P_WMinus, 272, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 1408, check)
      call createCurrent(P_Z, P_G0, 1517, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 817, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 1126, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 347, check)
      call createCurrent(P_uAnti, P_g, P_u, 1474, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 164, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 1421, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 1662, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 1168, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 1644, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 173, check)
      call createCurrent(P_b, P_H, P_bAnti, 892, check)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_muMinus, 1137, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 1325, check)
      call createCurrent(P_g, P_g, P_Zp, P_g, 1579, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 419, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 976, check)
      call createCurrent(P_nu_tau, P_ePlus, P_WpMinus, 1045, check)
      call createCurrent(P_H, P_ghWp, P_ghWpAnti, 1066, check)
      call createCurrent(P_dAnti, P_d, P_G0, 884, check)
      call createCurrent(P_G0, P_cAnti, P_c, 864, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 1053, check)
      call createCurrent(P_c, P_G0, P_cAnti, 805, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, P_H, 47, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 196, check)
      call createCurrent(P_Z, P_H, P_WPlus, P_GMinus, 163, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 694, check)
      call createCurrent(P_G0, P_d, P_sAnti, 364, check)
      call createCurrent(P_g, P_A, P_g, P_g, 1649, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 97, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WpPlus, 599, check)
      call createCurrent(P_H, P_G0, P_G0, 1296, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_Z, 1063, check)
      call createCurrent(P_WMinus, P_c, P_dAnti, 1490, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 1637, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 410, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 1621, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 1387, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 282, check)
      call createCurrent(P_g, P_Zp, P_g, P_A, 1548, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, 1360, check)
      call createCurrent(P_bAnti, P_b, P_H, 1040, check)
      call createCurrent(P_g, P_g, P_g, P_A, 1648, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 710, check)
      call createCurrent(P_A, P_dAnti, P_d, 969, check)
      call createCurrent(P_Z, P_H, P_GPlus, P_WMinus, 1497, check)
      call createCurrent(P_WMinus, P_g, P_WpPlus, P_g, 1646, check)
      call createCurrent(P_sAnti, P_s, 1537, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 405, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, P_H, 255, check)
      call createCurrent(P_s, P_Zp, P_dAnti, 83, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 556, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 278, check)
      call createCurrent(P_tAnti, P_t, 1530, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 935, check)
      call createCurrent(P_muMinus, P_nu_tauAnti, P_WpPlus, 858, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 881, check)
      call createCurrent(P_u, P_uAnti, P_G0, 795, check)
      call createCurrent(P_bAnti, P_WpMinus, P_c, 938, check)
      call createCurrent(P_H, P_tAnti, P_t, 1367, check)
      call createCurrent(P_t, P_G0, P_tAnti, 137, check)
      call createCurrent(P_H, P_H, P_Z, P_Z, 754, check)
      call createCurrent(P_WPlus, P_A, P_H, P_GMinus, 646, check)
      call createCurrent(P_GMinus, P_Z, P_H, P_WPlus, 901, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 155, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 1226, check)
      call createCurrent(P_WpPlus, P_tAnti, P_d, 559, check)
      call createCurrent(P_WpMinus, P_g, P_g, P_WpPlus, 1614, check)
      call createCurrent(P_WPlus, P_H, P_A, P_GMinus, 997, check)
      call createCurrent(P_cAnti, P_b, P_WpPlus, 846, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 1057, check)
      call createCurrent(P_t, P_H, P_tAnti, 412, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, P_H, 578, check)
      call createCurrent(P_tauMinus, P_nu_eAnti, P_WpPlus, 968, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WpMinus, 1597, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 992, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 626, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 541, check)
      call createCurrent(P_bAnti, P_WpMinus, P_u, 1417, check)
      call createCurrent(P_muMinus, P_ePlus, P_Zp, 354, check)
      call createCurrent(P_c, P_tAnti, P_Zp, 1345, check)
      call createCurrent(P_WPlus, P_WpMinus, P_g, P_g, 1601, check)
      call createCurrent(P_H, P_G0, P_H, P_G0, 115, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 129, check)
      call createCurrent(P_ePlus, P_eMinus, P_Zp, 295, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 1069, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 86, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 1450, check)
      call createCurrent(P_s, P_G0, P_dAnti, 335, check)
      call createCurrent(P_t, P_uAnti, P_Zp, 62, check)
      call createCurrent(P_H, P_uAnti, P_u, 221, check)
      call createCurrent(P_u, P_A, P_uAnti, 38, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 1005, check)
      call createCurrent(P_b, P_WpPlus, P_uAnti, 46, check)
      call createCurrent(P_A, P_u, P_uAnti, 1025, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 402, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 712, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 1247, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 446, check)
      call createCurrent(P_WpPlus, P_WpMinus, 1524, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, 387, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 1492, check)
      call createCurrent(P_s, P_uAnti, P_WpPlus, 814, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_Z, 1331, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 1055, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 1123, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, 383, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 273, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 629, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 1150, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 400, check)
      call createCurrent(P_g, P_Zp, P_A, P_g, 1546, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 358, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 1488, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 311, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 951, check)
      call createCurrent(P_b, P_Zp, P_dAnti, 853, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_Z, 73, check)
      call createCurrent(P_dAnti, P_s, P_Zp, 1023, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_H, 529, check)
      call createCurrent(P_muPlus, P_eMinus, P_Zp, 1463, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 52, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 183, check)
      call createCurrent(P_WPlus, P_s, P_uAnti, 936, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 275, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_H, 476, check)
      call createCurrent(P_H, P_GPlus, P_Z, P_WMinus, 463, check)
      call createCurrent(P_H, P_ghWm, P_ghWmAnti, 1381, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 553, check)
      call createCurrent(P_WpMinus, P_u, P_sAnti, 572, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 1412, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 1570, check)
      call createCurrent(P_Zp, P_g, P_A, P_g, 1540, check)
      call createCurrent(P_WpMinus, P_t, P_sAnti, 338, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 1414, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, 1343, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 294, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 1477, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 1590, check)
      call createCurrent(P_WpMinus, P_nu_tau, P_ePlus, 1289, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 806, check)
      call createCurrent(P_u, P_uAnti, P_H, 454, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 1068, check)
      call createCurrent(P_g, P_Zp, P_g, P_g, 1544, check)
      call createCurrent(P_G0, P_s, P_dAnti, 1194, check)
      call createCurrent(P_eMinus, P_Zp, P_tauPlus, 1319, check)
      call createCurrent(P_u, P_WMinus, P_sAnti, 1073, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 34, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 720, check)
      call createCurrent(P_g, P_A, P_g, P_A, 1573, check)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_muAnti, 362, check)
      call createCurrent(P_b, P_bAnti, P_H, 461, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 357, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, P_H, 1036, check)
      call createCurrent(P_d, P_dAnti, P_g, 1185, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WpPlus, 436, check)
      call createCurrent(P_WpMinus, P_sAnti, P_u, 1089, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 170, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 1458, check)
      call createCurrent(P_b, P_Zp, P_bAnti, 890, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 489, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 540, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 873, check)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, 406, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 1589, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 1617, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 648, check)
      call createCurrent(P_tAnti, P_Zp, P_u, 766, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, 1464, check)
      call createCurrent(P_u, P_WpMinus, P_sAnti, 381, check)
      call createCurrent(P_ePlus, P_tauMinus, P_Zp, 417, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_H, 434, check)
      call createCurrent(P_Z, P_WPlus, P_H, P_GMinus, 160, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_H, 448, check)
      call createCurrent(P_c, P_g, P_cAnti, 733, check)
      call createCurrent(P_c, P_cAnti, P_Z, 237, check)
      call createCurrent(P_H, P_G0, P_G0, P_H, 36, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 1415, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 1087, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, 675, check)
      call createCurrent(P_dAnti, P_Z, P_d, 1239, check)
      call createCurrent(P_u, P_bAnti, P_WpMinus, 1342, check)
      call createCurrent(P_ePlus, P_nu_mu, P_WpMinus, 1327, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 580, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 23, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 731, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 673, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 1431, check)
      call createCurrent(P_uAnti, P_u, P_G0, 298, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 727, check)
      call createCurrent(P_H, P_H, P_GMinus, P_GPlus, 426, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_H, 279, check)
      call createCurrent(P_tauMinus, P_muPlus, P_Zp, 908, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 865, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 484, check)
      call createCurrent(P_d, P_tAnti, P_WpPlus, 1299, check)
      call createCurrent(P_dAnti, P_b, P_Zp, 1029, check)
      call createCurrent(P_uAnti, P_H, P_u, 134, check)
      call createCurrent(P_g, P_WpPlus, P_WMinus, P_g, 1631, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 1608, check)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_muMinus, 100, check)
      call createCurrent(P_nu_eAnti, P_tauMinus, P_WpPlus, 826, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 1292, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 1678, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 1132, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 1439, check)
      call createCurrent(P_Zp, P_bAnti, P_b, 1153, check)
      call createCurrent(P_eMinus, P_Zp, P_muPlus, 356, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 706, check)
      call createCurrent(P_nu_muAnti, P_tauMinus, P_WpPlus, 404, check)
      call createCurrent(P_WpMinus, P_nu_mu, P_muPlus, 790, check)
      call createCurrent(P_tauPlus, P_Zp, P_eMinus, 220, check)
      call createCurrent(P_A, P_A, P_g, P_g, 1563, check)
      call createCurrent(P_g, P_A, P_g, P_Zp, 1663, check)
      call createCurrent(P_tauPlus, P_nu_e, P_WpMinus, 1401, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 1274, check)
      call createCurrent(P_dAnti, P_u, P_WpMinus, 1478, check)
      call createCurrent(P_b, P_bAnti, P_Z, 897, check)
      call createCurrent(P_nu_tau, P_WpMinus, P_muPlus, 1405, check)
      call createCurrent(P_Zp, P_uAnti, P_t, 654, check)
      call createCurrent(P_Z, P_Z, 1511, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 778, check)
      call createCurrent(P_b, P_sAnti, P_Zp, 202, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, 757, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 1, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 588, check)
      call createCurrent(P_t, P_bAnti, P_WpMinus, 1341, check)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_muMinus, 242, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 1468, check)
      call createCurrent(P_sAnti, P_Zp, P_d, 281, check)
      call createCurrent(P_nu_tauAnti, P_muMinus, P_WpPlus, 371, check)
      call createCurrent(P_Z, P_sAnti, P_s, 1223, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 20, check)
      call createCurrent(P_Zp, P_g, P_g, P_Zp, 1616, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 1329, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Zp, 548, check)
      call createCurrent(P_tAnti, P_s, P_WpPlus, 906, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 1170, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 319, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 525, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 389, check)
      call createCurrent(P_t, P_Zp, P_tAnti, 514, check)
      call createCurrent(P_Zp, P_dAnti, P_d, 1399, check)
      call createCurrent(P_eMinus, P_nu_muAnti, P_WpPlus, 459, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, 309, check)
      call createCurrent(P_s, P_uAnti, P_WPlus, 119, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 1344, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 737, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 1442, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 392, check)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_tau, 437, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, 166, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 1031, check)
      call createCurrent(P_u, P_Zp, P_uAnti, 443, check)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_tauMinus, 945, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 1581, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 667, check)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_eAnti, 236, check)
      call createCurrent(P_c, P_Zp, P_uAnti, 1409, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 226, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 970, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 1225, check)
      call createCurrent(P_cAnti, P_G0, P_c, 10, check)
      call createCurrent(P_WpMinus, P_dAnti, P_u, 1428, check)
      call createCurrent(P_H, P_A, P_GPlus, P_WMinus, 1302, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 269, check)
      call createCurrent(P_Zp, P_tauMinus, P_muPlus, 721, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 745, check)
      call createCurrent(P_WMinus, P_WPlus, 1534, check)
      call createCurrent(P_H, P_eMinus, P_ePlus, 800, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 1470, check)
      call createCurrent(P_bAnti, P_H, P_b, 1010, check)
      call createCurrent(P_WpPlus, P_d, P_uAnti, 564, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 1181, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 1633, check)
      call createCurrent(P_Z, P_Z, P_H, P_H, 967, check)
      call createCurrent(P_g, P_s, P_sAnti, 550, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, 1135, check)
      call createCurrent(P_Zp, P_muPlus, P_tauMinus, 24, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 1390, check)
      call createCurrent(P_WpMinus, P_c, P_dAnti, 931, check)
      call createCurrent(P_WMinus, P_A, P_H, P_GPlus, 713, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 248, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 1265, check)
      call createCurrent(P_c, P_A, P_cAnti, 1297, check)
      call createCurrent(P_Zp, P_b, P_sAnti, 302, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 1392, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 1145, check)
      call createCurrent(P_Z, P_g, P_Zp, P_g, 1565, check)
      call createCurrent(P_c, P_dAnti, P_GMinus, 181, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 135, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 1081, check)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_mu, 22, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 16, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 1298, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 928, check)
      call createCurrent(P_Zp, P_c, P_cAnti, 479, check)
      call createCurrent(P_cAnti, P_WPlus, P_d, 1051, check)
      call createCurrent(P_bAnti, P_b, 1531, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 779, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 1430, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 496, check)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_muAnti, 613, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 1588, check)
      call createCurrent(P_muPlus, P_nu_e, P_WpMinus, 1379, check)
      call createCurrent(P_t, P_tAnti, P_Z, 542, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 813, check)
      call createCurrent(P_nu_tau, P_muPlus, P_WpMinus, 1356, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 1277, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 871, check)
      call createCurrent(P_d, P_A, P_dAnti, 4, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 862, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 265, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 782, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 1549, check)
      call createCurrent(P_bAnti, P_u, P_WpMinus, 304, check)
      call createCurrent(P_ePlus, P_Zp, P_muMinus, 1161, check)
      call createCurrent(P_H, P_ePlus, P_eMinus, 1465, check)
      call createCurrent(P_WpMinus, P_g, P_WpPlus, P_g, 1595, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_H, 878, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 1407, check)
      call createCurrent(P_u, P_WpMinus, P_bAnti, 1082, check)
      call createCurrent(P_g, P_g, P_A, P_Zp, 1671, check)
      call createCurrent(P_WpPlus, P_s, P_uAnti, 882, check)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_tauMinus, 76, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 395, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 734, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 460, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 624, check)
      call createCurrent(P_s, P_sAnti, P_G0, 488, check)
      call createCurrent(P_dAnti, P_H, P_s, 431, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 1630, check)
      call createCurrent(P_GMinus, P_H, P_Z, P_WPlus, 1210, check)
      call createCurrent(P_H, P_WPlus, P_Z, P_GMinus, 1252, check)
      call createCurrent(P_u, P_WpMinus, P_dAnti, 953, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 1064, check)
      call createCurrent(P_ePlus, P_H, P_eMinus, 474, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 31, check)
      call createCurrent(P_sAnti, P_H, P_d, 159, check)
      call createCurrent(P_u, P_H, P_uAnti, 81, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 1099, check)
      call createCurrent(P_Z, P_t, P_tAnti, 538, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 1032, check)
      call createCurrent(P_ePlus, P_muMinus, P_Zp, 760, check)
      call createCurrent(P_Z, P_c, P_cAnti, 1027, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 1426, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 944, check)
      call createCurrent(P_H, P_GPlus, P_H, P_GMinus, 827, check)
      call createCurrent(P_sAnti, P_G0, P_d, 1438, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 1393, check)
      call createCurrent(P_b, P_g, P_bAnti, 598, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 1372, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, P_H, 1176, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 832, check)
      call createCurrent(P_muMinus, P_Zp, P_muPlus, 256, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 998, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, 755, check)
      call createCurrent(P_sAnti, P_WpMinus, P_t, 507, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 725, check)
      call createCurrent(P_c, P_Zp, P_tAnti, 390, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 411, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 1361, check)
      call createCurrent(P_WpPlus, P_uAnti, P_b, 1090, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 192, check)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_tauAnti, 1314, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 1643, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 1318, check)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_muAnti, 93, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, P_H, 1452, check)
      call createCurrent(P_H, P_dAnti, P_d, 1159, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 495, check)
      call createCurrent(P_WpPlus, P_d, P_cAnti, 1432, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 583, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, 1220, check)
      call createCurrent(P_H, P_c, P_cAnti, 126, check)
      call createCurrent(P_uAnti, P_u, P_A, 1287, check)
      call createCurrent(P_g, P_dAnti, P_d, 682, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 178, check)
      call createCurrent(P_Zp, P_sAnti, P_d, 1333, check)
      call createCurrent(P_d, P_Z, P_dAnti, 698, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_H, 775, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 268, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 318, check)
      call createCurrent(P_t, P_A, P_tAnti, 658, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_A, 1109, check)
      call createCurrent(P_G0, P_Z, P_H, 742, check)
      call createCurrent(P_cAnti, P_c, P_Z, 470, check)
      call createCurrent(P_uAnti, P_u, P_H, 659, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 662, check)
      call createCurrent(P_ghZ, P_H, P_ghZAnti, 919, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 520, check)
      call createCurrent(P_uAnti, P_WpPlus, P_b, 1118, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 818, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 937, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 79, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WpPlus, 1553, check)
      call createCurrent(P_WpMinus, P_nu_e, P_tauPlus, 1334, check)
      call createCurrent(P_H, P_H, P_WPlus, P_WMinus, 756, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 293, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 1131, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 1629, check)
      call createCurrent(P_d, P_dAnti, P_Zp, 229, check)
      call createCurrent(P_g, P_g, P_WpMinus, P_WPlus, 1604, check)
      call createCurrent(P_dAnti, P_G0, P_d, 573, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 501, check)
      call createCurrent(P_A, P_A, 1532, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 1236, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, 1281, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 386, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 1479, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 2, check)
      call createCurrent(P_cAnti, P_d, P_WpPlus, 1215, check)
      call createCurrent(P_cAnti, P_c, P_H, 909, check)
      call createCurrent(P_Zp, P_tauPlus, P_muMinus, 1193, check)
      call createCurrent(P_tAnti, P_g, P_t, 991, check)
      call createCurrent(P_t, P_WpMinus, P_bAnti, 288, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 774, check)
      call createCurrent(P_H, P_A, P_WPlus, P_GMinus, 1092, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 536, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 1098, check)
      call createCurrent(P_u, P_uAnti, P_A, 1062, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_H, 847, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 472, check)
      call createCurrent(P_t, P_cAnti, P_Zp, 424, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 41, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 1568, check)
      call createCurrent(P_WMinus, P_sAnti, P_u, 312, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 1306, check)
      call createCurrent(P_muMinus, P_tauPlus, P_Zp, 1008, check)
      call createCurrent(P_H, P_H, P_G0, P_G0, 1286, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, 605, check)
      call createCurrent(P_Zp, P_g, P_g, P_A, 1545, check)
      call createCurrent(P_g, P_WpMinus, P_WPlus, P_g, 1587, check)
      call createCurrent(P_cAnti, P_WpPlus, P_s, 1083, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 145, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 1574, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 1033, check)
      call createCurrent(P_d, P_Zp, P_dAnti, 960, check)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_muAnti, 1309, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 69, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(4)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(5)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(10)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(16)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(20)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(21)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(22)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(24)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(25)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(26)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(30)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(31)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(32)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(45)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(46)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(47)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(48)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(49)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(50)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(51)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(53)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(54)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(55)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(56)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(59)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(63)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(66)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(69)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(70)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(72)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
